@@ -2,6 +2,9 @@ use super::*;
 use alloc::string::ToString;
 use ritelinked::LinkedHashMap;
 
+/// The default prefix of the YAML sub tag.
+pub const DEFAULT_PREFIX: &str = "tag:yaml.org,2002:";
+
 /// The option of [`Parser::take_while`].
 pub enum TakeOpt {
     /// Match once.
@@ -20,7 +23,7 @@ impl<'a, R: repr::Repr> Parser<'a, R> {
     pub fn new(doc: &'a [u8]) -> Self {
         let mut tag = LinkedHashMap::new();
         tag.insert("!".to_string(), String::new());
-        tag.insert("!!".to_string(), "tag:yaml.org,2002:".to_string());
+        tag.insert("!!".to_string(), DEFAULT_PREFIX.to_string());
         Self {
             doc,
             indent: 2,
